% -*- compile-command: "texify --pdf --quiet cvmp_short.tex" -*-
% The above must be the first line
%------------------------------------------------------------------------------
% cvmp_short.cls   --   LaTeX2e class for CVMP Short Papers
%												Forked from CVMP extended Abstract in 2015
%------------------------------------------------------------------------------
% REVISION HISTORY
% 0.00 2007-03-29  Adrian F. Clark <alien/at/essex.ac.uk>
%      Original version.
% 0.01 2007-05-01  Adrian F. Clark <alien/at/essex.ac.uk>
%      Increase \headsep and tweak headline following comments from Roy Davies.
% 0.02 2008-10-01  Andrew Fitzgibbon <awf/at/microsoft.com>
%      Changes for cvmpC
% 0.03 2009-06-19  Andrew Fitzgibbon <awf/at/microsoft.com>
%      Added extended abstract for cvmpC
% 0.04 2009-06-22  Andrew Fitzgibbon <awf/at/microsoft.com>
%      Remove ``References'' from before bibliography
% 0.05 2009-06-22  Andrew Fitzgibbon <awf/at/microsoft.com>
%      Add pdfcatalog entry to display 2-up
% 0.06 2010-01-29  Alan Woodland <ajw/at/aber.ac.uk>
%      Bump year to 2010
% 0.07 2010-07-06  Andrew Fitzgibbon <awf/at/microsoft.com>
%      Add DOI
% 0.08 2011-03-01 Stephen McKenna <stephen/at/computing.dundee.ac.uk>
%      Change year to 2011
% 0.09 2011-04-07 Oliver Woodford <o.j.woodford.98/at/cantab.net>
%      Changed to use default mathcal font
%      Change year to 2011
% 0.10 2012-04-17 John Collomosse <j.collomosse/at/surrey.ac.uk>
%      Change year to 2012
% 0.11 2014-07-14 Michel Valstar <michel.valstar/at/nottingham.ac.uk>
%      Change year to 2014
% 0.12 2015-04-21 Adapted for CVMP Short Paper Format.
%------------------------------------------------------------------------------
% Copyright 2007 Adrian F. Clark <alien/at/essex.ac.uk>.  All rights reserved.
%------------------------------------------------------------------------------

% Notes on reading this file:
%
% 1.
% Private identifiers begin with cvmp@, identifiers intended for use by
% the authors are of two kinds: identifiers typically exported by
% ``article'' classes such as \addauthor, \maketitle, or \addinstitution;
% additional useful tools such as \CVMPOneDot, \CVMPHangBox, etc.
%
% 2.
% Lines ending with apparently innocuous comments are common in TeX
% source, because without them, spaces are inserted into the output.
% In this file I've tried to make these ``important'' comments begin
% with %^, to indicate that they have a structural purpose.  We use
% ^ because it's easy to type shift-56, and the ^ looks like an
% ``insert'' marker.
%
% 3.
% Debugging tips:
% \tracingmacros=1 % xx check this is unset before release...
%\def\cvmp@pdfcompresslevel{\global\pdfcompresslevel=0}  % xx this should also be unset for release
\let\cvmp@pdfcompresslevel=\relax  % xx this should also be unset for release

\newif\ifcvmp@pdf
\cvmp@pdffalse
\ifx\pdfoutput\undefined
\else
  \ifx\pdfoutput\relax
  \else
    \ifcase\pdfoutput
    \else
      \cvmp@pdftrue
    \fi
  \fi
\fi


%% Change the year...
\def\CVMP@year{2015}

%% -- CLASS FILE BOILERPLATE --

\def\fileversion{0.12}
\def\filedate{2015/04/21}

\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{cvmp_short}[\filedate\space CVMP Proceedings. v\fileversion]

\newif\ifcvmp@review
\cvmp@reviewfalse

\def\cvmp@papernumber{??}
\def\cvmpcreviewcopy#1{\cvmp@reviewtrue\global\def\cvmp@papernumber{#1}}

% We're based on the article class.
\ProcessOptions

\LoadClass[a4paper,twoside]{article}
\renewcommand{\normalsize}{\fontsize{9}{11pt}\selectfont}
\renewcommand{\small}{\fontsize{8}{9pt}\selectfont}
\renewcommand{\footnotesize}{\fontsize{7}{8pt}\selectfont}
\renewcommand{\scriptsize}{\fontsize{6}{8.5pt}\selectfont}
\renewcommand{\tiny}{\fontsize{5.5}{6.5pt}\selectfont}
\renewcommand{\large}{\fontsize{10}{12pt}\selectfont}
\renewcommand{\Large}{\fontsize{11}{12.5pt}\selectfont}
\renewcommand{\LARGE}{\fontsize{12}{14pt}\selectfont}
\renewcommand{\huge}{\fontsize{14}{16pt}\selectfont}
\renewcommand{\Huge}{\fontsize{16}{18pt}\selectfont}

\newcommand{\cvmp@titlesize}{\fontsize{11.5}{12.5pt}\selectfont}
\twocolumn

%% -- USEFUL PACKAGES --
\RequirePackage{color}
\RequirePackage{graphicx,subfigure}
\RequirePackage{xspace}
\RequirePackage{eso-pic}
\RequirePackage{url}

\DeclareUrlCommand\CVMPUrl{\urlstyle{sf}}

\usepackage{amsmath}

%% -- USER-VISIBLE MACROS --

%% \CVMPOneDot{e.g}
% Add a period to the end of an abbreviation unless there's one
% already, then \xspace.
\DeclareRobustCommand\CVMPOneDot{\futurelet\@let@token\cvmp@onedotaux}
\def\cvmp@onedotaux{\ifx\@let@token.\else.\null\fi\xspace}

%% \CVMPCenterBox{Line 1\\Line 2}
% Center lines in a box.  This expands its argument twice, so any side
% effects (e.g. incrementing a counter) will be observed twice
\newbox\cvmp@CenterBoxtmp
\def\CVMPCenterBox#1{%^
 % First measure the width
 \setbox\cvmp@CenterBoxtmp\hbox{%^
   \begin{minipage}{2\textwidth}%^
     \begin{tabbing}#1\end{tabbing}%^
   \end{minipage}}%^
 % And then make the minipage
 \begin{minipage}[t]{\wd\cvmp@CenterBoxtmp}%^
   \begin{center}#1\end{center}%^
 \end{minipage}}

%% \CVMPHangBox{Text}
% Proper hanging from top o f first line, not bottom.  i.e.
%   \cvmp@hang{\epsfbox{pic1.ps}}\cvmp@hang{\epsfbox{pic2.ps}}
% will produce
%   -----  -----
%   | 1 |  | 2 |
%   -----  |   |
%          -----
%
% 

\def\CVMPHangBox#1{%^
\begin{minipage}[t]{\textwidth}% Top-hanging minipage, will align on
			       % bottom of first line
\begin{tabbing} % tabbing so that minipage shrinks to fit
~\\[-\baselineskip] % Make first line zero-height
#1 % Include user's text
\end{tabbing}%^
\end{minipage}} % can't allow } onto next line, as {WIDEBOX}~x will not tie.


\def\CVMPBaselineHangBox#1{%^
\begin{minipage}[t]{\textwidth}% Top-hanging minipage, will align on
			       % bottom of first line
\begin{tabbing} % tabbing so that minipage shrinks to fit
#1 % Include user's text
\end{tabbing}
\end{minipage}} % can't allow } onto next line, as {WIDEBOX}~x will not tie.

%%  --  PAGE LAYOUT  --
% Extended abstract:
% A single A4 page, for printed booklet. Pages are centered
% horizontally, as they will be shifted left and right at print time.
\RequirePackage[twoside,headsep=3mm,a4paper,inner=11mm,outer=11mm,top=3mm,includehead,bottom=8mm,heightrounded]{geometry}
\columnsep=3mm

% Set up the fonts.

\RequirePackage[T1]{fontenc}
\RequirePackage{mathptmx}
\RequirePackage{helvet,courier}
\DeclareMathAlphabet{\mathcal}{OMS}{cmsy}{m}{n}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% INTERNALS

% xx
% pdfTeX warning (ext4): destination with the same identifier
% (name{}) has been already used, duplicate ignored
%

% Debug flag: set to 1 to see boxes around authors/insts
\let\CVMPdebug=0
\newif\ifCVMPdebug
\ifx\CVMPdebug 1
\CVMPdebugtrue
\else
\CVMPdebugfalse
\fi

% Colours for debugging
\ifCVMPdebug
\definecolor{cvmp@PaleBlue}{rgb}{.7,.7,1}
\definecolor{cvmp@PalePink}{rgb}{1,.7,.7}
\else
\definecolor{cvmp@PaleBlue}{rgb}{1,1,1}
\definecolor{cvmp@PalePink}{rgb}{1,1,1}
\fi

\definecolor{cvmp@sectioncolor}{rgb}{0,0.75,0.9}
\definecolor{cvmp@captioncolor}{rgb}{0,0.75,0.9}

\ifCVMPdebug
\message{Style file debugging on}
\fi

%% cvmp@edefappend -- expand token list and append to macro #1
\newtoks\cvmp@toks
\def\cvmp@edefappend#1#2{%^
  \cvmp@toks = \expandafter{#1}%^
  \xdef#1{\the\cvmp@toks #2}%^
}

%% Useful macros for named boxes and counters

% named boxes
\def\cvmp@newbox#1{\expandafter \newbox \csname cvmp@box #1 \endcsname}
\def\cvmp@sbox#1#2{\expandafter \sbox \csname cvmp@box #1 \endcsname {#2}}
\def\cvmp@savenewbox#1#2{\cvmp@newbox{#1}\cvmp@sbox{#1}{#2}}
\def\cvmp@unhbox#1{\expandafter\unhbox \csname cvmp@box #1 \endcsname}
\def\cvmp@usebox#1{\expandafter\usebox \csname cvmp@box #1 \endcsname}

% named counters
\def\cvmp@newcount#1{\expandafter \newcount \csname cvmp@cnt #1 \endcsname}
\def\cvmp@setcountaux#1#2{#1=#2}
\def\cvmp@setcount#1#2{\expandafter \cvmp@setcountaux \csname cvmp@cnt #1 \endcsname {#2}}
\def\cvmp@thecount#1{\expandafter \the \csname cvmp@cnt #1 \endcsname}

% struts
% These are visible in debug mode
\ifCVMPdebug
\def\cvmp@strut{\rule{0.1pt}{1ex}\hspace{-0.1pt}}
\else
\def\cvmp@strut{\rule{0pt}{1ex}}
\fi

%% Generic List Map
\let\cvmp@endstop=\relax

% cvmp@maplistaux -- macro \cvmp@action is called with each token in list up to
% next \cvmp@endstop, calling macro \cvmp@between between items.
\def\cvmp@maplistaux#1{%^
 \cvmp@action{#1}%^
 \@ifnextchar\cvmp@endstop{\@gobble}{\cvmp@between\cvmp@maplistaux}%^
}

% executing \between between each

% e.g. \cvmp@maplist\fbox{-o-}{{fred}{una}{conor}}

% reminder of ~ catcodes
% \catcode`\~=12  \def~{\char`~}  % code is ``7E

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% AUTHOR AND INSTITUTION HANDLING

%% CVMPResetAuthors -- Empty author/institution lists for testing
\def\CVMPResetAuthors{
  \cvmp@nauthors=0
  \cvmp@ninsts=0
  \edef\cvmp@auths{}
  \edef\cvmp@insts{}
  \gdef\maketitle{\cvmp@maketitle}
}

% We will explictly count the authors in cvmp@nauthors
% just to keep the code a bit clearer
\newcount\cvmp@nauthors 
\cvmp@nauthors=0

% cvmp@ninsts -- Number of institutions
\newcount\cvmp@ninsts
\cvmp@ninsts=0

% cvmp@auths -- stores the author ids as a list of length n
\edef\cvmp@auths{}

% cvmp@insts -- stores the institutions as a list of length n
\edef\cvmp@insts{}

% \cvmp@RenderAuthorName -- Place the author's name in a box
\def\cvmp@RenderAuthorName#1{%^
  \sffamily\normalsize #1}

% \cvmp@RenderAuthorNameFN -- Place the author's name in a box with a footnotemark
\def\cvmp@RenderAuthorNameFN#1#2{%^
  \sffamily\normalsize #1$^{\mbox{\sffamily\scriptsize #2}}$}

% \cvmp@RenderAuthorMail -- Place the author's mail/www in a box
\def\cvmp@RenderAuthorMail#1{%^
  \small\textcolor{cvmp@sectioncolor}{\CVMPUrl{#1}}}

% \addauthor{Name}{email/homepage}{INSTITUTION_CODE}
\def\addauthor#1#2#3{%^
  \advance\cvmp@nauthors1
  \cvmp@savenewbox{authname\the\cvmp@nauthors}{\cvmp@RenderAuthorName{#1}}
  \cvmp@savenewbox{authnameFN\the\cvmp@nauthors}{\cvmp@RenderAuthorNameFN{#1}{#3}}
  \cvmp@savenewbox{authmail\the\cvmp@nauthors}{\cvmp@RenderAuthorMail{#2}}
  \cvmp@newcount{authinst\the\cvmp@nauthors}
  \cvmp@setcount{authinst\the\cvmp@nauthors}{#3}
  \cvmp@edefappend{\cvmp@auths}{\the\cvmp@nauthors}
}

% \cvmp@RenderInst{Name\\Address}
% Display an institution address
\def\cvmp@RenderInst#1{%^
   \begin{minipage}[t]{0.48\textwidth}
    \sffamily
    \begin{raggedright}
     #1
    \end{raggedright}
   \end{minipage}}

% \addinstitution{Name\\Address}
% This creates two display boxes: one with footnotemark, 
% and one without. We make the boxes now so that we can 
% deal with them without worrying about subsequent macro 
% expansion.
\long\def\addinstitution#1{
  \advance\cvmp@ninsts1
  \cvmp@savenewbox{inst\the\cvmp@ninsts}{\cvmp@RenderInst{#1}}
  \cvmp@savenewbox{instFN\the\cvmp@ninsts}{%^
    \sffamily$\rule{0pt}{1ex}^{\mbox{\scriptsize \the\cvmp@ninsts}}\,$%^
    \hbox{\cvmp@RenderInst{#1}}}
  \cvmp@edefappend{\cvmp@insts}{\the\cvmp@ninsts}
}

\def\cvmp@RAIspace{\hspace*{2pt}}

% \cvmp@RenderAuthInstTwoColumn 
% Display authors on left and institutions on right 
% Add footnotes if 
\def\cvmp@RenderAuthInstTwoColumn{
% Use footnotes if more than one institution
% In future, one might be cleverer if the author order and 
% institution order are both ascending
\ifnum\cvmp@ninsts>1
 \def\cvmp@FN{FN}
\else
 \def\cvmp@FN{}
\fi
% A minipage for the authors, on the left
\begin{minipage}[t]{0.49\textwidth}
 \def\cvmp@action##1{%^
  \cvmp@unhbox{authname\cvmp@FN##1}\\
  \cvmp@unhbox{authmail##1}}
 \def\cvmp@between{\\[3pt]}
 \expandafter\cvmp@maplistaux\cvmp@auths\cvmp@endstop
\end{minipage}
\cvmp@RAIspace\hfill%^
% A minipage for the institutions, on the right
\begin{minipage}[t]{0.48\textwidth}
 \def\cvmp@action##1{%^
  \cvmp@unhbox{inst\cvmp@FN##1}}
 \def\cvmp@between{\\[4pt]}
 \expandafter\cvmp@maplistaux\cvmp@insts\cvmp@endstop
\end{minipage}
}

% \cvmp@RenderAuthInstTable 
% Display authors on left and institutions on right,
% but look up the institution for each author
\def\cvmp@RenderAuthInstTable{
\def\cvmp@FN{}
\let\cvmp@action=\cvmp@RAITableAction
\def\cvmp@between{\\[4pt]}
\expandafter\cvmp@maplistaux\cvmp@auths\cvmp@endstop
}

\def\cvmp@RAITableAction#1{
\begin{minipage}[t]{0.49\textwidth}
\cvmp@unhbox{authname#1}\\
\cvmp@unhbox{authmail#1}
\end{minipage}
\cvmp@RAIspace~
\begin{minipage}[t]{0.48\textwidth}
\cvmp@usebox{inst\cvmp@thecount{authinst#1}}
\end{minipage}
}

%% cvmp@RenderAuthorsAndInstitutions
% Make author list, but not in ``review'' mode...
\def\cvmp@RenderAuthorsAndInstitutions{
% Send them to the page
\ifnum\cvmp@ninsts=1
\cvmp@RenderAuthInstTwoColumn
\else
% more than one institution.
%  if equal to number of authors, then there's one each, so
%  render one each..
\ifnum\cvmp@ninsts=\cvmp@nauthors
\cvmp@RenderAuthInstTable
\else
\cvmp@RenderAuthInstTwoColumn
\fi
\fi

}


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Email addresses are enclosed in angle brackets.  (The \<...> macro
% can also be used independently, though it works only outside maths mode.)

%\def\<#1>{$\langle$#1$\rangle$}
%\def\email#1{\<\texttt{#1}>}

% A macro for producing the title, which also puts the copyright notice
% in an unnumbered footnote on the first page.  The \maketitle macro
% was derived from a (probably very old) version of the article class
% and is probably not as elegant as it could be.

\newcounter{CVMP@shortyear}
\setcounter{CVMP@shortyear}\CVMP@year
\addtocounter{CVMP@shortyear}{-1986}

\def\cvmp@maketitle{\newpage\global\@topnum\z@%^
  \cvmp@strut\\[-4pt]% vglue produces inconsistent results
  \begin{raggedright}%^
    {\cvmp@titlesize\bfseries\sffamily\textcolor{cvmp@sectioncolor} \@title\par}%^
    \vskip 1em%^
    {\cvmp@RenderAuthorsAndInstitutions}%^
  \end{raggedright}%^
  \vskip\baselineskip
  \textcolor{cvmp@sectioncolor}{\hrule}
  \vskip\baselineskip
  \def\CVMP@blfootnote{\xdef\@thefnmark{}\@footnotetext}%^
  \CVMP@blfootnote{\null\hspace{-1.9em}\copyright{} \CVMP@year.
    The copyright of this document resides with its authors.    
\\
    It may be distributed unchanged freely in print or electronic forms.}%^
  \setcounter{footnote}{0}%^
  \thispagestyle{cvmp@c}\pagestyle{cvmp@c}%^
  \gdef\maketitle{\message{Cannot use maketitle twice}}%^
}

\def\maketitle{\twocolumn[\cvmp@maketitle]}

% The running head contains the author(s) and paper title, perhaps
% abbreviated so that the overall length of the headline is not too long.

\def\runninghead#1#2{\gdef\CVMP@author{\MakeUppercase{#1}}%^
  \gdef\CVMP@title{\MakeUppercase{#2}}}

% The et al macro allows for a lowercase ``et al.'' in the running head.
% It is called using \protect\etal
\def\cvmp@EtAl{\em et al.}
\def\CVMPEtAl{\protect\cvmp@EtAl}


% A macro that saves out the number of the last page of the document
% in the macro \CVMP@LastPage, for use in the headline.

\AtEndDocument{\immediate\write\@auxout{\gdef\string\CVMP@LastPage{\thepage}}}
\def\CVMP@LastPage{??}

% The headline itself, which comprises two lines of text:
%   -- The first contains the paper's authors and title and is a
%      hypertext reference to the master version on the Annals website.
%   -- The second gives citation information, with the journal name
%      being a hypertext reference to the Annals website.
% This has to be set explicitly by the author (or editor) via the \papernumber
% macro (see above).

\def\CVMP@authorOrAnon{\ifcvmp@review{AUTHOR(S)}\else\CVMP@author\fi}


\newcommand*{\ps@cvmp@c}{%^
\renewcommand*{\@oddhead}{}%^
\renewcommand*{\@evenhead}{}%^
\renewcommand*{\@oddfoot}{}%^
\renewcommand*{\@evenfoot}{}%^
}
% Ensure section titles are set ragged-right.   These definitions are
% adapted from those in article.cls v1.4f of 2004/02/16.

\renewcommand\section{\@startsection {section}{1}{\z@}%^
                                   {-3.5ex \@plus -1ex \@minus -.2ex}%^
                                   {2.3ex \@plus.2ex}%^
                                   {\normalfont\Large\bfseries\flushleft\textcolor{cvmp@sectioncolor}}}
\renewcommand\subsection{\@startsection{subsection}{2}{\z@}%^
                                     {-3.25ex\@plus -1ex \@minus -.2ex}%^
                                     {1.5ex \@plus .2ex}%^
                                     {\normalfont\large\bfseries\flushleft\textcolor{cvmp@sectioncolor}}}
\renewcommand\subsubsection{\@startsection{subsubsection}{3}{\z@}%^
                                     {-3.25ex\@plus -1ex \@minus -.2ex}%^
                                     {1.5ex \@plus .2ex}%^
                                     {\normalfont\normalsize\bfseries\flushleft\textcolor{cvmp@sectioncolor}}}

% Footnote rules go right across the page (definition adapted from
% article.cls v1.4f of 2004/02/16).

\renewcommand\footnoterule{\kern-3\p@
  \hrule\@width\columnwidth
  \kern2.6\p@}

% Make the space above figure captions more compact
\setlength\abovecaptionskip{-5pt}

% Set captions in blue
\let\cvmp@makecaption=\@makecaption
\def\@makecaption#1#2{\textcolor{cvmp@captioncolor}{\cvmp@makecaption{#1}{#2}}}

 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% RULER
%% --------- Page background marks: Ruler and confidentiality

% ----- define vruler
\newbox\cvmp@rulerbox
\newcount\cvmp@rulercount
\newdimen\cvmp@ruleroffset
\newdimen\cvmp@rulerlineheight
\newdimen\cvmp@rulerboxheight
\newbox\cvmp@rulertmpbox
\newcount\cvmp@rulerrefno
\newcount\cvmp@rulertot

\font\cvmp@ruler@tenhv = phvb at 8pt % *** If this fails, see the lines after this one in cvmpc2k.sty ***
% If the above lines give an error message, try to comment them and
% uncomment these:
%\font\cvmp@ruler@tenhv = phvb7t at 8pt 

%% \fillzeros[<WIDTH>]<NUMBER>
% NUMBER with left flushed zeros
\newcount\cvmp@rulertmpc@
\newcount\cvmp@rulertmpc
\def\cvmp@fillzeros[#1]#2{
  \cvmp@rulertmpc@=#2\relax\ifnum\cvmp@rulertmpc@<0\cvmp@rulertmpc@=-\cvmp@rulertmpc@\fi
\cvmp@rulertmpc=1 %^
\loop\ifnum\cvmp@rulertmpc@<10 \else \divide\cvmp@rulertmpc@ by 10 \advance\cvmp@rulertmpc by 1 \fi
   \ifnum\cvmp@rulertmpc@=10\relax\cvmp@rulertmpc@=11\relax\fi \ifnum\cvmp@rulertmpc@>10 \repeat
\ifnum#2<0\advance\cvmp@rulertmpc1\relax-\fi
\loop\ifnum\cvmp@rulertmpc<#1\relax0\advance\cvmp@rulertmpc1\relax\fi \ifnum\cvmp@rulertmpc<#1 \repeat
\cvmp@rulertmpc@=#2\relax\ifnum\cvmp@rulertmpc@<0\cvmp@rulertmpc@=-\cvmp@rulertmpc@\fi
\relax\the\cvmp@rulertmpc@}

% \makevruler[<SCALE>][<INITIAL_COUNT>][<STEP>][<DIGITS>][<HEIGHT>]
\def\makevruler[#1][#2][#3][#4][#5]{\begingroup\offinterlineskip
\textheight=#5\vbadness=10000\vfuzz=120ex\overfullrule=0pt%^
\global\setbox\cvmp@rulerbox=\vbox to \textheight{%^
{\parskip=0pt\hfuzz=150em\cvmp@rulerboxheight=\textheight
\cvmp@rulerlineheight=#1\global\cvmp@rulercount=#2%^
\cvmp@rulertot\cvmp@rulerboxheight\divide\cvmp@rulertot\cvmp@rulerlineheight\advance\cvmp@rulertot2%^
\cvmp@rulerrefno1\vskip-\cvmp@rulerlineheight\vskip1ex%^
\loop\setbox\cvmp@rulertmpbox=\hbox to0cm{{\cvmp@ruler@tenhv\hfil\cvmp@fillzeros[#4]\cvmp@rulercount}}%^
\ht\cvmp@rulertmpbox\cvmp@rulerlineheight\dp\cvmp@rulertmpbox0pt\box\cvmp@rulertmpbox\break
\advance\cvmp@rulerrefno1\global\advance\cvmp@rulercount#3\relax
\ifnum\cvmp@rulerrefno<\cvmp@rulertot\repeat}}\endgroup}%^
% ----- end of vruler

% \makevruler[<SCALE>][<INITIAL_COUNT>][<STEP>][<DIGITS>][<HEIGHT>]
\def\cvmp@ruler#1{\makevruler[12.5pt][#1][1][3][0.993\textheight]\usebox{\cvmp@rulerbox}}
\AddToShipoutPicture{%^
  %\AtTextLowerLeft{%^
  % \color[gray]{.15}\framebox(\LenToUnit{\textwidth},\LenToUnit{\textheight}){}
  %}
  \ifcvmp@review
  \cvmp@ruleroffset=\textheight
  \advance\cvmp@ruleroffset by 1pt
  \color[rgb]{.7,.7,1}
  \AtTextUpperLeft{%^
    \ifodd\c@page
    \put(\LenToUnit{-21pt},\LenToUnit{-\cvmp@ruleroffset}){%left ruler
      \cvmp@ruler{\cvmp@rulercount}}
    \else
    \put(\LenToUnit{\textwidth\kern3pt},\LenToUnit{-\cvmp@ruleroffset}){%right ruler
      \cvmp@ruler{\cvmp@rulercount}}
    \fi
  }
  \fi
}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Bibliography stuff.

% Natbib gives sorting of numeric references.
% We don't use the compress option, because we
% want each reference to have its own popup
\usepackage[sort,numbers]{cvmp_natbib}

% Compressed bibliography for the 1-pager
\def\bibsection{} % No ``References'' header
\bibsep=2pt

\newif\ifcvmp@annot
\cvmp@annotfalse
\def\cvmp@annotation{}
\definecolor{cvmp@CiteBoxColor}{rgb}{1,1,1}

\def\Hy@StartlinkName#1#2{%^  #1 is object props -- ignored for us
  \ifcvmp@annot%^
  \setbox\@tempboxa=\hbox{\textcolor{cvmp@CiteBoxColor}{{CVMPtest~}}}%^
  \immediate\pdfxform\@tempboxa%^
  \edef\cvmp@theblank{\the\pdflastxform}%^
   \pdfannot {  % This annot will be given a bounding box corresponding to
		% its surrounding hbox
    % We use a ``square'' Annot because we want it to scale with the text
    /A << /D << /S /GoTo /D (#2) >> >> ^^J
    /Subtype /Square ^^J
    /Subj (Citation) ^^J
    /CA 1.0
    /T (Citation) ^^J
    /Contents (\cvmp@annotation) ^^J
    /XAP << % Appearance 
      /N \cvmp@theblank\space 0 R
      /D \cvmp@theblank\space 0 R
      /R \cvmp@theblank\space 0 R
    >> ^^J
    /Open false
   }%^
  \else
    \pdfstartlink attr{#1 /PTEX.FullName (CVMPtest) }goto name{#2}\relax 
  \fi}

% hook into the natbib/hyperref citation hooks.
\bibliographystyle{plainnat}

%------------------------------------------------------------------------------
% End of cvmp_short.cls
%------------------------------------------------------------------------------
\message{Finished loading cvmp_short}
